Module request

Module request 

Types for Coinbase WebSocket API subscription requests and responses.

This module provides types for serializing and deserializing subscription requests, channels, and error responses for the Coinbase WebSocket API.

Structs

Error
Represents an error response from the Coinbase WebSocket API.
Request
Represents a subscription request.
SubscriptionChannel
Represents a subscription channel.
Subscriptions
Represents the current subscriptions.

Enums

RequestType
Represents the type of request for subscriptions.